First release.

Dependencies:   FXOS8700CQ SDFileSystem mbed

Final program

  • Controling a robot by Bluetooth, it is capable of making 90° turns and move pre-defined distances.

Code by:

  • Mayumi Hori
  • Sarahí Morán
  • Gerardo Carmona
Revision:
2:94059cb643be
Parent:
1:ab09b233da7b
Child:
3:bd16e43ad7be
--- a/main.cpp	Thu Oct 16 15:48:57 2014 +0000
+++ b/main.cpp	Thu Oct 16 17:30:52 2014 +0000
@@ -7,10 +7,10 @@
     
     COMPONENTS:
     * Bluetooth
     * Magnometer    (FXOS8700CQ & magnometer.h)
     * Motors        (motors.h)
     * Encoder
     * Ultrasonics
     
     CONTROLS:
     w: foward
@@ -26,12 +26,16 @@
     * Gerardo Carmona
     
     VERSION:
-    1.1 - 10/16/14
+    1.2 - 10/16/14
+    
 
     HISTORY:
+    1.2 - 10/16/14
+    (+) Added xbee, ultrasonic, sd_card
+    
     1.1 - 10/16/14
     (*) Some bug fixes
-    (*) Added encoder.h and encpoder.cpp (empty files)
+    (+) Added encoder.h and encpoder.cpp (empty files)
     
     1.0 - 10/14/14
     (+) Initial release.
@@ -43,6 +47,9 @@
 #include "mbed.h"
 #include "motors.h"
 #include "magnometer.h"
+#include "encoder.h"
+#include "sd_card.h"
+#include "xbee.h"
 
 // ----- Constants ------------------------------------------------------------------
 #define LED_ERROR       6
@@ -87,7 +94,6 @@
     //fxos.enable();
     leds = LED_NORMAL;
     bt_timer.start();
-    
     while (true){
         if (bt_timer.read_ms() >= BT_TIME){
             bt_data = read_bt();
@@ -7,10 +7,10 @@
     COMPONENTS:
     * Bluetooth
-    * Magnometer    (FXOS8700CQ & magnometer.h)
-    * Motors        (motors.h)
-    * Encoder
-    * Ultrasonics
+    * Magnometer            (FXOS8700CQ & magnometer.h)
+    * Motors                (motors.h)
+    * Encoder   
+    * Ultrasonic sensors    (motors.h)
     
     CONTROLS: